# organelles_config files
The `organelles_config` files layout the step-wise process available in each `organelle-segmenter-plugin` workflow.

- "conf_....json" files specify the steps for each workflow
- "all_functions.json" contains the specifics for each workflow step calling functions from infer_subc

The logic for each workflow is also explained in the [Notebooks](/docs/nbs/overview.md).

